Data documentation compiled by Great Expectations

Documentation autogenerated using Great Expectations.

This is a beta feature! Expect changes in API, behavior, and design.
Table of Contents

### Expectation Suite Overview

#### Info

Full Data Asset Identifier | random/default/f1
Data Asset Type | Dataset
Expectation Suite Name | BasicDatasetProfiler
Great Expectations Version | 0.8.5+17.gd5141147

#### Table-Level Expectations

- Must have more than 0 rows.
- This table should have a list of columns in a specific order, but that order is not specified.

#### Notes

This Expectation suite currently contains 13 total Expectations across 2 columns.

To add additional notes, edit the `meta.notes.content` field in the appropriate Expectation json file.

### Unnamed: 0

- value types must belong to this set: BIGINT BYTEINT DECIMAL INT INTEGER IntegerType LongType SMALLINT TINYINT int.
- may have any number of unique values.
- may have any fraction of unique values.
- values must not be null, at least 50 % of the time.
- values must belong to this set: [ ].
- values must be unique.

### Unnamed: 1

- value types must belong to this set: DOUBLE_PRECISION DoubleType FLOAT FLOAT4 FLOAT8 FloatType NUMERIC float.
- may have any number of unique values.
- may have any fraction of unique values.
- values must not be null, at least 50 % of the time.
- values must belong to this set: [ ].

Documentation autogenerated using Great Expectations.

This is a beta feature! Expect changes in API, behavior, and design.